pub struct FixedStateRootQuery<N: Network> {
pub state_root: N::StateRoot,
pub block_height: u32,
}Expand description
Custom query returning a fixed state root (bypasses ureq/WAF issues).
Fields
state_root: N::StateRootblock_height: u32Trait Implementations
Sourceimpl<N: Network> QueryTrait<N> for FixedStateRootQuery<N>
impl<N: Network> QueryTrait<N> for FixedStateRootQuery<N>
Sourcefn current_state_root(&self) -> Result<N::StateRoot>
fn current_state_root(&self) -> Result<N::StateRoot>
Returns the current state root.
Sourcefn current_block_height(&self) -> Result<u32>
fn current_block_height(&self) -> Result<u32>
Returns the current block height
Sourcefn get_state_path_for_commitment(
&self,
_commitment: &Field<N>,
) -> Result<StatePath<N>>
fn get_state_path_for_commitment( &self, _commitment: &Field<N>, ) -> Result<StatePath<N>>
Returns a state path for the given
commitment.Sourcefn get_state_paths_for_commitments(
&self,
_commitments: &[Field<N>],
) -> Result<Vec<StatePath<N>>>
fn get_state_paths_for_commitments( &self, _commitments: &[Field<N>], ) -> Result<Vec<StatePath<N>>>
Returns a list of state paths for the given list of
commitments.Sourcefn current_state_root_async<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<N::StateRoot>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn current_state_root_async<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<N::StateRoot>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns the current state root.
Sourcefn current_block_height_async<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u32>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn current_block_height_async<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u32>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns the current block height
Sourcefn get_state_path_for_commitment_async<'life0, 'life1, 'async_trait>(
&'life0 self,
_commitment: &'life1 Field<N>,
) -> Pin<Box<dyn Future<Output = Result<StatePath<N>>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_state_path_for_commitment_async<'life0, 'life1, 'async_trait>(
&'life0 self,
_commitment: &'life1 Field<N>,
) -> Pin<Box<dyn Future<Output = Result<StatePath<N>>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Returns a state path for the given
commitment.Sourcefn get_state_paths_for_commitments_async<'life0, 'life1, 'async_trait>(
&'life0 self,
_commitments: &'life1 [Field<N>],
) -> Pin<Box<dyn Future<Output = Result<Vec<StatePath<N>>>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_state_paths_for_commitments_async<'life0, 'life1, 'async_trait>(
&'life0 self,
_commitments: &'life1 [Field<N>],
) -> Pin<Box<dyn Future<Output = Result<Vec<StatePath<N>>>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Returns a list of state paths for the given list of
commitments.Auto Trait Implementations
impl<N> Freeze for FixedStateRootQuery<N>
impl<N> RefUnwindSafe for FixedStateRootQuery<N>
impl<N> Send for FixedStateRootQuery<N>
impl<N> Sync for FixedStateRootQuery<N>
impl<N> Unpin for FixedStateRootQuery<N>
impl<N> UnsafeUnpin for FixedStateRootQuery<N>
impl<N> UnwindSafe for FixedStateRootQuery<N>